@@ -1,4 +1,5 @@
 use strict;
+use Encode qw(decode_utf8 encode_utf8);
 use Unicode::LineBreak;
 
 $Unicode::LineBreak::Config = {
@@ -6,10 +7,16 @@ $Unicode::LineBreak::Config = {
     Mapping => 'EXTENDED',
     Replacement => 'DEFAULT',
     Charset => 'UTF-8',
+    Context => '',
+    Format => 'DEFAULT',
     HangulAsAL => 'NO',
-    OutputCharset => 'UTF-8',
-    Break => "\n",
+    Language => 'XX',
+    LegacyCM => "YES",
     MaxColumns => 76,
+    Newline => "\n",
+    NSKanaAsID => "NO",
+    OutputCharset => 'UTF-8',
+    SizingMethod => "DEFAULT",
 };
 
 sub dotest {
@@ -17,10 +24,10 @@ sub dotest {
     my $out = shift;
 
     open IN, "<testin/$in.in" or die "open: $!";
-    my $instring = join '', <IN>;
+    my $instring = decode_utf8(join '', <IN>);
     close IN;
-    my $lb = Unicode::LineBreak->new($instring, @_);
-    $instring = $lb->break();
+    my $lb = Unicode::LineBreak->new(@_);
+    my $broken = encode_utf8($lb->break($instring));
     #open XXX, ">testin/$out.xxx";
     #print XXX $instring;
     #close XXX;
@@ -29,7 +36,7 @@ sub dotest {
     my $outstring = join '', <OUT>;
     close OUT;
 
-    is($instring, $outstring);
+    is($broken, $outstring);
 }    
 
 1;
